@@ -68,52 +68,6 @@
 #define MINIMUM_ON_SCREEN_HEIGHT	100
 
 
-/**
- * eel_gtk_signal_connect_free_data_custom:
- * 
- * Attach a function pointer and user data to a signal, and call a
- * a destroy function on the user data when the signal is disconnected.
- * @object: the object which emits the signal. For example, a button in the button press signal.
- * @name: the name of the signal.
- * @func: function pointer to attach to the signal.
- * @data: the user data associated with the function.
- * @destroy_func: the function to call on the user data when the signal
- * is disconnected.
- **/
-guint
-eel_gtk_signal_connect_free_data_custom (GtkObject       *object,
-					 const gchar     *name,
-					 GtkSignalFunc    func,
-					 gpointer         data,
-					 GtkDestroyNotify destroy_func)
-{
-	return g_signal_connect_closure (
-		object, name,
-		g_cclosure_new (func, data, (GClosureNotify) destroy_func),
-		FALSE);
-}
-
-/**
- * eel_gtk_signal_connect_free_data:
- * 
- * Attach a function pointer and user data to a signal, and free
- * the user data when the signal is disconnected.
- * @object: the object which emits the signal. For example, a button in the button press signal.
- * @name: the name of the signal.
- * @func: function pointer to attach to the signal.
- * @data: the user data associated with the function. g_free() will be called on
- * this user data when the signal is disconnected.
- **/
-guint
-eel_gtk_signal_connect_free_data (GtkObject *object,
-				       const gchar *name,
-				       GtkSignalFunc func,
-				       gpointer data)
-{
-	return eel_gtk_signal_connect_free_data_custom
-		(object, name, func, data, g_free);
-}
-
 /**
  * eel_gtk_window_get_geometry_string:
  * @window: a #GtkWindow
