@@ -2156,7 +2156,8 @@ eel_labeled_image_accessible_get_name (AtkObject *accessible)
 
 	labeled_image = get_image (accessible);
 
-	if (labeled_image->details->label)
+	if (labeled_image && labeled_image->details &&
+	    labeled_image->details->label)
 		return gtk_label_get_text
 			(GTK_LABEL (labeled_image->details->label));
 
